summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--pr/src/md/unix/darwin.c6
-rw-r--r--pr/src/md/unix/rhapsody.c6
2 files changed, 6 insertions, 6 deletions
diff --git a/pr/src/md/unix/darwin.c b/pr/src/md/unix/darwin.c
index 04000437..a68f8667 100644
--- a/pr/src/md/unix/darwin.c
+++ b/pr/src/md/unix/darwin.c
@@ -78,11 +78,11 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
/* These functions should not be called for OSF1 */
void
_MD_YIELD(void)
{
- PR_NOT_REACHED("_MD_YIELD should not be called for OSF1.");
+ PR_NOT_REACHED("_MD_YIELD should not be called for Rhapsody.");
}
PRStatus
@@ -94,7 +94,7 @@ _MD_CREATE_THREAD(
PRThreadState state,
PRUint32 stackSize)
{
- PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for OSF1.");
+ PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for Rhapsody.");
return PR_FAILURE;
}
#endif /* ! _PR_PTHREADS */
@@ -78,11 +78,11 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
-/* These functions should not be called for OSF1 */
+/* These functions should not be called for Rhapsody */
void
_MD_YIELD(void)
diff --git a/pr/src/md/unix/rhapsody.c b/pr/src/md/unix/rhapsody.c
index 04000437..a68f8667 100644
--- a/pr/src/md/unix/rhapsody.c
+++ b/pr/src/md/unix/rhapsody.c
@@ -78,11 +78,11 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
/* These functions should not be called for OSF1 */
void
_MD_YIELD(void)
{
- PR_NOT_REACHED("_MD_YIELD should not be called for OSF1.");
+ PR_NOT_REACHED("_MD_YIELD should not be called for Rhapsody.");
}
PRStatus
@@ -94,7 +94,7 @@ _MD_CREATE_THREAD(
PRThreadState state,
PRUint32 stackSize)
{
- PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for OSF1.");
+ PR_NOT_REACHED("_MD_CREATE_THREAD should not be called for Rhapsody.");
return PR_FAILURE;
}
#endif /* ! _PR_PTHREADS */
@@ -78,11 +78,11 @@ _MD_WAKEUP_WAITER(PRThread *thread)
return PR_SUCCESS;
}
-/* These functions should not be called for OSF1 */
+/* These functions should not be called for Rhapsody */
void
_MD_YIELD(void)